class DoNotFindThis:
    """pyi files should be preferred."""
